pub struct SegmentDimensionFilter {
pub case_sensitive: Option<bool>,
pub dimension_name: Option<String>,
pub expressions: Option<Vec<String>>,
pub max_comparison_value: Option<String>,
pub min_comparison_value: Option<String>,
pub operator: Option<String>,
}Expand description
Dimension filter specifies the filtering options on a dimension.
This type is not used in any activity, and only used as part of another schema.
Fields
case_sensitive: Option<bool>Should the match be case sensitive, ignored for IN_LIST operator.
dimension_name: Option<String>Name of the dimension for which the filter is being applied.
expressions: Option<Vec<String>>The list of expressions, only the first element is used for all operators
max_comparison_value: Option<String>Maximum comparison values for BETWEEN match type.
min_comparison_value: Option<String>Minimum comparison values for BETWEEN match type.
operator: Option<String>The operator to use to match the dimension with the expressions.