pub struct SegmentFilterClause {
pub dimension_filter: Option<SegmentDimensionFilter>,
pub metric_filter: Option<SegmentMetricFilter>,
pub not: Option<bool>,
}Expand description
Filter Clause to be used in a segment definition, can be wither a metric or a dimension filter.
This type is not used in any activity, and only used as part of another schema.
Fields
dimension_filter: Option<SegmentDimensionFilter>Dimension Filter for the segment definition.
metric_filter: Option<SegmentMetricFilter>Metric Filter for the segment definition.
not: Option<bool>Matches the complement (!) of the filter.